==> telepathy-salut_0.5.0.orig.tar.gz: telepathy-salut-0.5.0/tests/twisted/ns.py <==
AMP = "http://jabber.org/protocol/amp"
BYTESTREAMS = 'http://jabber.org/protocol/bytestreams'
CHAT_STATES = 'http://jabber.org/protocol/chatstates'
CAPS = "http://jabber.org/protocol/caps"
DISCO_INFO = "http://jabber.org/protocol/disco#info"
DISCO_ITEMS = "http://jabber.org/protocol/disco#items"
FEATURE_NEG = 'http://jabber.org/protocol/feature-neg'
FILE_TRANSFER = 'http://jabber.org/protocol/si/profile/file-transfer'
GEOLOC = 'http://jabber.org/protocol/geoloc'
GOOGLE_FEAT_SESSION = 'http://www.google.com/xmpp/protocol/session'
GOOGLE_FEAT_SHARE = 'http://google.com/xmpp/protocol/share/v1'
GOOGLE_FEAT_VOICE = 'http://www.google.com/xmpp/protocol/voice/v1'
GOOGLE_FEAT_VIDEO = 'http://www.google.com/xmpp/protocol/video/v1'
GOOGLE_JINGLE_INFO = 'google:jingleinfo'
GOOGLE_P2P = "http://www.google.com/transport/p2p"
GOOGLE_QUEUE = 'google:queue'
GOOGLE_ROSTER = 'google:roster'
GOOGLE_SESSION = "http://www.google.com/session"
GOOGLE_SESSION_SHARE = "http://www.google.com/session/share"
GOOGLE_SESSION_PHONE = "http://www.google.com/session/phone"
GOOGLE_SESSION_VIDEO = "http://www.google.com/session/video"
GOOGLE_MAIL_NOTIFY = "google:mail:notify"
IBB = 'http://jabber.org/protocol/ibb'
JINGLE_015 = "http://jabber.org/protocol/jingle"
JINGLE_015_AUDIO = "http://jabber.org/protocol/jingle/description/audio"
JINGLE_015_VIDEO = "http://jabber.org/protocol/jingle/description/video"
JINGLE = "urn:xmpp:jingle:1"
JINGLE_RTP = "urn:xmpp:jingle:apps:rtp:1"
JINGLE_RTP_AUDIO = "urn:xmpp:jingle:apps:rtp:audio"
JINGLE_RTP_VIDEO = "urn:xmpp:jingle:apps:rtp:video"
JINGLE_RTP_ERRORS = "urn:xmpp:jingle:apps:rtp:errors:1"
JINGLE_RTP_INFO_1 = "urn:xmpp:jingle:apps:rtp:info:1"
JINGLE_TRANSPORT_ICEUDP = "urn:xmpp:jingle:transports:ice-udp:1"
JINGLE_TRANSPORT_RAWUDP = "urn:xmpp:jingle:transports:raw-udp:1"
MUC = 'http://jabber.org/protocol/muc'
MUC_BYTESTREAM = 'http://telepathy.freedesktop.org/xmpp/protocol/muc-bytestream'
MUC_OWNER = '%s#owner' % MUC
MUC_USER = '%s#user' % MUC
NICK = "http://jabber.org/protocol/nick"
NS_XMPP_SASL = 'urn:ietf:params:xml:ns:xmpp-sasl'
NS_XMPP_BIND = 'urn:ietf:params:xml:ns:xmpp-bind'
NS_XMPP_TLS  = 'urn:ietf:params:xml:ns:xmpp-tls'
NS_XMPP_SESSION = 'urn:ietf:params:xml:ns:xmpp-session'
OLPC_ACTIVITIES = "http://laptop.org/xmpp/activities"
OLPC_ACTIVITIES_NOTIFY = "%s+notify" % OLPC_ACTIVITIES
OLPC_ACTIVITY = "http://laptop.org/xmpp/activity"
OLPC_ACTIVITY_PROPS = "http://laptop.org/xmpp/activity-properties"
OLPC_ACTIVITY_PROPS_NOTIFY = "%s+notify" % OLPC_ACTIVITY_PROPS
OLPC_BUDDY = "http://laptop.org/xmpp/buddy"
OLPC_BUDDY_PROPS = "http://laptop.org/xmpp/buddy-properties"
OLPC_BUDDY_PROPS_NOTIFY = "%s+notify" % OLPC_BUDDY_PROPS
OLPC_CURRENT_ACTIVITY = "http://laptop.org/xmpp/current-activity"
OLPC_CURRENT_ACTIVITY_NOTIFY = "%s+notify" % OLPC_CURRENT_ACTIVITY
PUBSUB = "http://jabber.org/protocol/pubsub"
PUBSUB_EVENT = "%s#event" % PUBSUB
REGISTER = "jabber:iq:register"
ROSTER = "jabber:iq:roster"
SEARCH = 'jabber:iq:search'
SI = 'http://jabber.org/protocol/si'
SI_MULTIPLE = 'http://telepathy.freedesktop.org/xmpp/si-multiple'
STANZA = "urn:ietf:params:xml:ns:xmpp-stanzas"
STREAMS = "urn:ietf:params:xml:ns:xmpp-streams"
TEMPPRES = "urn:xmpp:temppres:0"
TUBES = 'http://telepathy.freedesktop.org/xmpp/tubes'
MUJI = 'http://telepathy.freedesktop.org/xmpp/muji'
VCARD_TEMP = 'vcard-temp'
VCARD_TEMP_UPDATE = 'vcard-temp:x:update'
X_DATA = 'jabber:x:data'
X_DELAY = 'jabber:x:delay'
XML = 'http://www.w3.org/XML/1998/namespace'
X_OOB = 'jabber:x:oob'
IQ_OOB = 'jabber:iq:oob'
GABBLE_CAPS="http://telepathy.freedesktop.org/caps"
PRESENCE_INVISIBLE = 'presence-invisible'
PRIVACY = 'jabber:iq:privacy'
INVISIBLE = 'urn:xmpp:invisible:0'
GOOGLE_SHARED_STATUS = 'google:shared-status'
VERSION = 'jabber:iq:version'

==> telepathy-salut_0.8.1.orig.tar.gz: telepathy-salut-0.8.1/tests/twisted/ns.py <==
AMP = "http://jabber.org/protocol/amp"
BYTESTREAMS = 'http://jabber.org/protocol/bytestreams'
CHAT_STATES = 'http://jabber.org/protocol/chatstates'
CAPS = "http://jabber.org/protocol/caps"
DISCO_INFO = "http://jabber.org/protocol/disco#info"
DISCO_ITEMS = "http://jabber.org/protocol/disco#items"
FEATURE_NEG = 'http://jabber.org/protocol/feature-neg'
FILE_TRANSFER = 'http://jabber.org/protocol/si/profile/file-transfer'
GEOLOC = 'http://jabber.org/protocol/geoloc'
GOOGLE_FEAT_SESSION = 'http://www.google.com/xmpp/protocol/session'
GOOGLE_FEAT_SHARE = 'http://google.com/xmpp/protocol/share/v1'
GOOGLE_FEAT_VOICE = 'http://www.google.com/xmpp/protocol/voice/v1'
GOOGLE_FEAT_VIDEO = 'http://www.google.com/xmpp/protocol/video/v1'
GOOGLE_JINGLE_INFO = 'google:jingleinfo'
GOOGLE_P2P = "http://www.google.com/transport/p2p"
GOOGLE_QUEUE = 'google:queue'
GOOGLE_ROSTER = 'google:roster'
GOOGLE_SESSION = "http://www.google.com/session"
GOOGLE_SESSION_SHARE = "http://www.google.com/session/share"
GOOGLE_SESSION_PHONE = "http://www.google.com/session/phone"
GOOGLE_SESSION_VIDEO = "http://www.google.com/session/video"
GOOGLE_MAIL_NOTIFY = "google:mail:notify"
IBB = 'http://jabber.org/protocol/ibb'
JINGLE_015 = "http://jabber.org/protocol/jingle"
JINGLE_015_AUDIO = "http://jabber.org/protocol/jingle/description/audio"
JINGLE_015_VIDEO = "http://jabber.org/protocol/jingle/description/video"
JINGLE = "urn:xmpp:jingle:1"
JINGLE_RTP = "urn:xmpp:jingle:apps:rtp:1"
JINGLE_RTP_AUDIO = "urn:xmpp:jingle:apps:rtp:audio"
JINGLE_RTP_VIDEO = "urn:xmpp:jingle:apps:rtp:video"
JINGLE_RTP_ERRORS = "urn:xmpp:jingle:apps:rtp:errors:1"
JINGLE_RTP_INFO_1 = "urn:xmpp:jingle:apps:rtp:info:1"
JINGLE_TRANSPORT_ICEUDP = "urn:xmpp:jingle:transports:ice-udp:1"
JINGLE_TRANSPORT_RAWUDP = "urn:xmpp:jingle:transports:raw-udp:1"
MUC = 'http://jabber.org/protocol/muc'
MUC_BYTESTREAM = 'http://telepathy.freedesktop.org/xmpp/protocol/muc-bytestream'
MUC_OWNER = '%s#owner' % MUC
MUC_USER = '%s#user' % MUC
NICK = "http://jabber.org/protocol/nick"
NS_XMPP_SASL = 'urn:ietf:params:xml:ns:xmpp-sasl'
NS_XMPP_BIND = 'urn:ietf:params:xml:ns:xmpp-bind'
NS_XMPP_TLS  = 'urn:ietf:params:xml:ns:xmpp-tls'
NS_XMPP_SESSION = 'urn:ietf:params:xml:ns:xmpp-session'
OLPC_ACTIVITIES = "http://laptop.org/xmpp/activities"
OLPC_ACTIVITIES_NOTIFY = "%s+notify" % OLPC_ACTIVITIES
OLPC_ACTIVITY = "http://laptop.org/xmpp/activity"
OLPC_ACTIVITY_PROPS = "http://laptop.org/xmpp/activity-properties"
OLPC_ACTIVITY_PROPS_NOTIFY = "%s+notify" % OLPC_ACTIVITY_PROPS
OLPC_BUDDY = "http://laptop.org/xmpp/buddy"
OLPC_BUDDY_PROPS = "http://laptop.org/xmpp/buddy-properties"
OLPC_BUDDY_PROPS_NOTIFY = "%s+notify" % OLPC_BUDDY_PROPS
OLPC_CURRENT_ACTIVITY = "http://laptop.org/xmpp/current-activity"
OLPC_CURRENT_ACTIVITY_NOTIFY = "%s+notify" % OLPC_CURRENT_ACTIVITY
PUBSUB = "http://jabber.org/protocol/pubsub"
PUBSUB_EVENT = "%s#event" % PUBSUB
REGISTER = "jabber:iq:register"
ROSTER = "jabber:iq:roster"
SEARCH = 'jabber:iq:search'
SI = 'http://jabber.org/protocol/si'
SI_MULTIPLE = 'http://telepathy.freedesktop.org/xmpp/si-multiple'
STANZA = "urn:ietf:params:xml:ns:xmpp-stanzas"
STREAMS = "urn:ietf:params:xml:ns:xmpp-streams"
TEMPPRES = "urn:xmpp:temppres:0"
TUBES = 'http://telepathy.freedesktop.org/xmpp/tubes'
MUJI = 'http://telepathy.freedesktop.org/xmpp/muji'
VCARD_TEMP = 'vcard-temp'
VCARD_TEMP_UPDATE = 'vcard-temp:x:update'
X_DATA = 'jabber:x:data'
X_DELAY = 'jabber:x:delay'
XML = 'http://www.w3.org/XML/1998/namespace'
X_OOB = 'jabber:x:oob'
IQ_OOB = 'jabber:iq:oob'
GABBLE_CAPS="http://telepathy.freedesktop.org/caps"
PRESENCE_INVISIBLE = 'presence-invisible'
PRIVACY = 'jabber:iq:privacy'
INVISIBLE = 'urn:xmpp:invisible:0'
GOOGLE_SHARED_STATUS = 'google:shared-status'
VERSION = 'jabber:iq:version'
TP_FT_METADATA_SERVICE = 'http://telepathy.freedesktop.org/xmpp/file-transfer-service'
TP_FT_METADATA = 'http://telepathy.freedesktop.org/xmpp/file-transfer-metadata'
